@@ -116,7 +116,7 @@ class Kfzcheck(object):
         about.set_copyright("(c) Patrick Beck")
         about.set_comments(_("KFZcheck searches for kfz license plates shortcuts and citys - german example: S for Stuttgart. It has a german list with car shortcuts and the according citys included.")) 
         about.set_website("http://wiki.yourse.de/doku.php?id=python:kfzcheck")
-        about.set_logo(gtk.gdk.pixbuf_new_from_file("kfzcheck.png"))
+        about.set_logo(gtk.gdk.pixbuf_new_from_file("/usr/share/pixmaps/kfzcheck.png"))
         about.run()
         about.destroy()
 
